/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

const fs = require('fs')
const path = require('path')
const mkdirp = require('mkdirp')
const install = require('spawn-npm-install')

const Plugins = require('../../util/Plugins')
const output = require('../../output')

module.exports = function (name) {
  if (name.indexOf('cli-') < 0) {
    name = '@includable/cli-' + name
  }

  if (!fs.existsSync(Plugins.packageFile)) {
    const json = {
      'private': true,
      'name': 'my-inc-plugins',
      'description': 'Auto-generated by the Includable CLI!',
      'version': '0.0.1',
      'license': 'MIT',
      'dependencies': {}
    }

    mkdirp.sync(path.dirname(Plugins.packageFile))
    fs.writeFileSync(Plugins.packageFile, JSON.stringify(json, null, 3), 'utf8')
  }

  const spinner = output.wait('Installing plugin...')
  install(name, {
    cwd: Plugins.directory,
    noShrinkwrap: true,
    production: true,
    noBinLinks: true,
    save: true
  }, function (err, res) {
    spinner()

    if (err) {
      output.errSimple(err.message)
      return
    }

    output.success('+ Installed 1 plugin.')
  })
}
