/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

/*
 * Version 1.0 to 1.1
 *
 *  move .scholica -> .inc/containers/default.json
 *  move .scholica.dev -> .inc/containers/beta.json
 *  move .phpstorm.meta.php -> .inc/meta/.phpstorm.meta.php
 *  file .inc/version
 *  edit .gitignore
 */

const path = require('path')
const eol = require('eol')
const fs = require('fs')

const removeArrayItem = function (arr, itemToRemove) {
  return arr.filter(function (item) {
    return item !== itemToRemove
  })
}

const updateGitignore = function () {
  if (!fs.existsSync('.gitignore')) {
    return
  }

  var lines = fs.readFileSync('.gitignore', 'utf8')
  lines = eol.split(lines)
  lines = removeArrayItem(lines, '/.scholica')
  lines = removeArrayItem(lines, '/.scholica.beta')
  lines = removeArrayItem(lines, '.scholica')
  lines = removeArrayItem(lines, '.scholica.beta')
  lines = removeArrayItem(lines, '.phpstorm.meta.php')
  lines = removeArrayItem(lines, '.container')
  lines = removeArrayItem(lines, '.container.dev')

  if (!lines[lines.length - 1].length) {
    lines[lines.length - 1] = '.inc'
  } else {
    lines.push('.inc')
  }

  lines.push('')

  fs.writeFileSync('.gitignore', lines.join(eol.auto), 'utf8')
}

const moveContainerFiles = function () {
  if (fs.existsSync('.scholica')) {
    fs.renameSync('.scholica', path.join('.inc', 'containers', 'default.json'))
  }
  if (fs.existsSync('.scholica.beta')) {
    fs.renameSync('.scholica.beta', path.join('.inc', 'containers', 'beta.json'))
  }
}

module.exports = function () {
  if (!fs.existsSync('.inc')) {
    fs.mkdirSync('.inc')
    fs.mkdirSync(path.join('.inc', 'containers'))
    fs.mkdirSync(path.join('.inc', 'meta'))

    moveContainerFiles()
    updateGitignore()

    if (fs.existsSync('.phpstorm.meta.php')) {
      fs.renameSync('.phpstorm.meta.php', path.join('.inc', 'meta', '.phpstorm.meta.php'))
    }

    fs.writeFileSync(path.join('.inc', 'version'), '11', 'utf8')
  }
}
