/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const fs = require('fs')
const path = require('path')
const chalk = require('chalk')
const jsonfile = require('jsonfile')

const output = require('../output')
const util = require('../util')
const Module = require('../containers/Module')

const dir = util.getPluginsDirectory()
const pkg = path.join(dir, 'package.json')

const Plugins = {
  directory: dir,
  plugins: getDirectories(),
  packageFile: pkg
}

function getDirectories () {
  try {
    var deps = jsonfile.readFileSync(pkg)
    if (!deps || !deps.dependencies || typeof deps.dependencies !== 'object') {
      return []
    }
    return Object.keys(deps.dependencies).filter(function (file) {
      return fs.existsSync(path.join(dir, 'node_modules', file, 'package.json'))
    })
  } catch (e) {
    // Do nothing
  }

  return []
}

Plugins.applyPlugins = function (program) {
  // Patch 'program'
  program.util = util
  program.request = util.request
  program.output = output
  program.module = Module
  program.plugins = Plugins

  // Read directories
  for (var x in Plugins.plugins) {
    if (!Plugins.plugins.hasOwnProperty(x)) {
      continue
    }

    require(path.join(dir, 'node_modules', Plugins.plugins[x]))(program)
  }
}

Plugins.listPlugins = function () {
  for (var x in Plugins.plugins) {
    if (!Plugins.plugins.hasOwnProperty(x)) {
      continue
    }

    Plugins.describePlugin(Plugins.plugins[x])
  }
}

Plugins.describePlugin = function (pluginName) {
  var info = require(path.join(dir, 'node_modules', pluginName, 'package.json'))
  var title = chalk.underline(info.name) + ' (' + info.version + ')'
  if ('description' in info && info.description && info.description.length) {
    title += '\n  ' + info.description
  }

  output.log(title)
}

module.exports = Plugins
